@@ -9,7 +9,7 @@ import logging
 from rich.progress import Progress, SpinnerColumn, TextColumn, MofNCompleteColumn, BarColumn, TimeElapsedColumn, TimeRemainingColumn
 
 
-WORKER = '[bold cyan]TRAINER[/bold cyan]'
+WORKER = 'TRAINER'
 
 
 _EVAL_FUNCTIONS = {
@@ -378,7 +378,7 @@ class Evaluator:
         self.device = device
     
     def _eval_model_detailed(self, data_loader, device, binary = True):
-        model =  self.ModelModule.model
+        model =  self.ModelModule
         model.eval()
         print('generating detailed evaluation..')
         
