@@ -4,6 +4,7 @@ import os
 import shortuuid
 import json
 import torch
+import logging
 
 def get_config(params):
     # random pick a set of params
@@ -19,7 +20,7 @@ def get_config(params):
         config[name] = choice
     return config
 
-def save_model(model, tokenizer, model_name, save_path, files, save_mode=None):
+def save_model(model, model_id, tokenizer, model_name, save_path, files, save_mode=None):
     """
     model - model
     tokenizer - tokenizer intialized using transformer
@@ -27,8 +28,7 @@ def save_model(model, tokenizer, model_name, save_path, files, save_mode=None):
     save_path - path
     files - dict of files with key to be names and values to be files to be saved in the same directory, have to be all json files
     """                  
-    # generate ID
-    model_id = shortuuid.ShortUUID().random(length=12)
+    
                     
     if not os.path.isdir(save_path):
         os.mkdir(save_path) # create directory if not exist
@@ -36,6 +36,8 @@ def save_model(model, tokenizer, model_name, save_path, files, save_mode=None):
     # change here 
     save_path_final = os.path.join(save_path, model_id + '-' + model_name)
 
+    logging.info(f'Model Saved to {save_path_final}')
+
     if not os.path.isdir(save_path_final):
         os.mkdir(save_path_final) # create directory for model if not exist
     
@@ -58,6 +60,7 @@ def save_model(model, tokenizer, model_name, save_path, files, save_mode=None):
 
     # save tokenizer
     tokenizer.save_pretrained(save_path_final)
+
     
     # save file in the files
     for file_name in files:
